<?php
    
    namespace common\models;
    
    use artbox\core\behaviors\LanguageBehavior;
    use artbox\core\models\Image;
    use artbox\core\models\Language;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;
    use Yii;
    
    /**
     * This is the model class for table "persone".
     *
     * @property integer       $id
     * @property integer       $image_id
     * @property PersoneLang[] $personeLangs
     * @property Language[]    $languages
     * @property Image         $image
     * @property string        $instagram
     * @property string        $facebook
     *      * From language behavior *
     * @property PersoneLang   $lang
     * @property PersoneLang[] $langs
     * @property PersoneLang   $objectLang
     * @property string        $ownerKey
     * @property string        $langKey
     * @property PersoneLang[] $modelLangs
     * @property bool          $transactionStatus
     * @method string       getOwnerKey()
     * @method void         setOwnerKey( string $value )
     * @method string       getLangKey()
     * @method void         setLangKey( string $value )
     * @method ActiveQuery  getLangs()
     * @method ActiveQuery  getLang( integer $language_id )
     * @method PersoneLang[]   generateLangs()
     * @method void         loadLangs( Request $request )
     * @method bool         linkLangs()
     * @method bool         saveLangs()
     * @method bool         getTransactionStatus()
     * @method bool         loadWithLangs( Request $request )
     * @method bool         saveWithLangs()
     *      * End language behavior *
     * @see LanguageBehavior
     */
    class Persone extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'persone';
        }
        
        public function behaviors()
        {
            return [
                'language' => [
                    'class' => LanguageBehavior::className(),
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'image_id' ],
                    'integer',
                ],
                [
                    [
                        'facebook',
                        'instagram',
                    ],
                    'string',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'        => Yii::t('app', 'ID'),
                'image_id'  => Yii::t('app', 'Image ID'),
                'facebook'  => Yii::t('app', 'Facebook'),
                'instagram' => Yii::t('app', 'Instagram'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getImage()
        {
            return $this->hasOne(Image::className(), [ 'id' => 'image_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getPersoneLangs()
        {
            return $this->hasMany(PersoneLang::className(), [ 'persone_id' => 'id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(Language::className(), [ 'id' => 'language_id' ])
                        ->viaTable('persone_lang', [ 'persone_id' => 'id' ]);
        }
    }
