<?php
    
    namespace common\models;
    
    use artbox\core\behaviors\SlugBehavior;
    use artbox\core\models\Alias;
    use artbox\core\models\Language;
    use Yii;
    use yii\db\ActiveRecord;
    
    /**
     * This is the model class for table "persone_lang".
     *
     * @property integer  $persone_id
     * @property integer  $language_id
     * @property integer  $alias_id
     * @property string   $title
     * @property string   $preview
     * @property string   $text
     * @property Language $language
     * @property Alias    $alias
     * @property Persone  $persone
     */
    class PersoneLang extends ActiveRecord
    {
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'persone_lang';
        }
        
        /**
         * @inheritdoc
         */
        public static function primaryKey()
        {
            return [
                'persone_id',
                'language_id',
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'slug' => [
                    'class'  => SlugBehavior::className(),
                    'action' => 'persone/view',
                    'params' => [
                        'id' => 'persone_id',
                    ],
                    'fields' => [],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'persone_id',
                        'language_id',
                        'alias_id',
                    ],
                    'integer',
                ],
                [
                    [
                        'text',
                        'preview',
                    ],
                    'string',
                ],
                [
                    [ 'title' ],
                    'string',
                    'max' => 255,
                ],
                [
                    [
                        'persone_id',
                        'language_id',
                    ],
                    'unique',
                    'targetAttribute' => [
                        'persone_id',
                        'language_id',
                    ],
                    'message'         => 'The combination of Persone ID and Language ID has already been taken.',
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'id' ],
                ],
                [
                    [ 'persone_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Persone::className(),
                    'targetAttribute' => [ 'persone_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'persone_id'  => Yii::t('app', 'Persone ID'),
                'language_id' => Yii::t('app', 'Language ID'),
                'alias_id'    => Yii::t('app', 'Alias ID'),
                'title'       => Yii::t('app', 'Title'),
                'text'        => Yii::t('app', 'Text'),
                'preview'     => Yii::t('app', 'Preview'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'id' => 'language_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getPersone()
        {
            return $this->hasOne(Persone::className(), [ 'id' => 'persone_id' ]);
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getAlias()
        {
            return $this->hasOne(Alias::className(), [ 'id' => 'alias_id' ]);
        }
    }
