<?php
    namespace frontend\controllers;
    
    use common\models\Feedback;
    use artbox\core\models\Page;
    use common\models\Gallery;
    use common\models\Settings;
    use frontend\models\CommentPage;
    use Yii;
    use yii\filters\VerbFilter;
    use yii\swiftmailer\Mailer;
    use yii\web\BadRequestHttpException;
    use yii\web\Controller;
    use yii\web\Response;
    
    /**
     * Site controller
     */
    class SiteController extends Controller
    {
        /**
         * @inheritdoc
         */
        public function actions()
        {
            return [
                'error' => [
                    'class' => 'yii\web\ErrorAction',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'verbs' => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'feedback' => [ 'post' ],
                    ],
                ],
            ];
        }
        
        /**
         * Displays homepage.
         *
         * @return mixed
         */
        public function actionIndex()
        {
    
            $aliasIdsForBlog = [1, 2, 3];
            $this->view->params['aliases'] = \artbox\core\models\Alias::find()
                                                                      ->where(
                                                                          [
                                                                              'id' => $aliasIdsForBlog
                                                                          ]
                                                                      )
                                                                      ->all();
            
            return $this->render('index');
        }
        
        /**
         * Displays contact page.
         *
         * @return mixed
         */
        public function actionContact()
        {
            $contact = new Feedback(['scenario'=>Feedback::SCENARIO_WRITE_US]);
    
            $aliasIdsForBlog = [95, 96, 97];
            $this->view->params['aliases'] = \artbox\core\models\Alias::find()
                                                                      ->where(
                                                                          [
                                                                              'id' => $aliasIdsForBlog
                                                                          ]
                                                                      )
                                                                      ->all();
            
            return $this->render(
                'contact',
                [
                    'contact' => $contact,
                ]
            );
        }
        
        /**
         * Displays about page.
         *
         * @return mixed
         */
        public function actionAbout()
        {

            $page_about = Page::find()
                ->with('lang')
                ->where([ 'id' => 6 ])
                ->one();

            return $this->render(
                'about',
                [
                    'page_about' => $page_about,
                ]
            );
        }
        
        /**
         * Action to view robots.txt file dinamycli
         *
         * @return string
         */
        public function actionRobots()
        {
            $response = \Yii::$app->response;
            /**
             * @var Settings $settings
             */
            $settings = Settings::find()
                                ->one();
            $temp = tmpfile();
            fwrite($temp, $settings->robots);
            $meta = stream_get_meta_data($temp);
            $response->format = $response::FORMAT_RAW;
            $response->headers->set('Content-Type', 'text/plain');
            return $this->renderFile($meta[ 'uri' ]);
        }
        
        public function actionFeedback()
        {
            Yii::$app->response->format = Response::FORMAT_JSON;
            
            /**
             * @var Mailer $mailer
             */
            $mailer = \Yii::$app->get('smtpmailer');
            $settings = Settings::getInstance();
            
            if (empty(Yii::$app->request->post())) {
                throw new BadRequestHttpException();
            } else {
                $type = Yii::$app->request->post("type");
    
                $viewFileName = "feedback";
                $model = new Feedback(['scenario' => Feedback::SCENARIO_WRITE_US]);
    
                if ( $type === "write_us" ){
                    $viewFileName = "feedback";
                    $model = new Feedback(['scenario' => Feedback::SCENARIO_WRITE_US]);
                }
                elseif ( $type === "appointment" ){
                    $viewFileName = "appointment";
                    $model = new Feedback(['scenario' => Feedback::SCENARIO_APPOINTMENT]);
                }
                
                
                if ($model->load(Yii::$app->request->post()) && $model->save()) {
    
                    $pattern = '/([a-zA-Z0-9\._-]*@[a-zA-Z0-9\._-]*)([;\s,:]*)/';
                    $replacement = '$1; ';
                    $emailStr = preg_replace($pattern, $replacement, $settings->email);
                    $emailStr = mb_substr($emailStr, 0, -2); // remove last "; " 2 symbols
                    
                    $emails = explode("; ", $emailStr);
                    
                    
                    $mailer->compose(
                        $viewFileName,
                        [
                            'model' => $model,
                        ]
                    )
                           ->setFrom('artbox@domain.com')
                           ->setTo($emails)
                           ->setSubject(\Yii::t('app', 'Feedback'))
                           ->send();
                    
                    $alert = "<div class=\"alert alert-success\">
                                <h3>".\Yii::t('app', 'Success')."</h3>
                                <p style='margin-bottom: 15px;'>".\Yii::t('app', 'Success Text')."</p>
                            </div>";
                    
                    return [
                        'success' => true,
                        'message' => 'Success message',
                        'alert'   => $alert,
                        'type' => $type,
                    ];
                } else {
                    Yii::$app->response->setStatusCode(500);
                    
                    return [
                        'success' => false,
                        'error'   => $model->errors,
                    ];
                }
            }
        }
        
        public function actionAppment()
        {
            return $this->render('appment');
        }
        
        public function actionPrice()
        {
            $page_stom = Page::find()
                             ->with('lang')
                             ->where([ 'id' => 22 ])
                             ->one();
            $page_cosm = Page::find()
                             ->with('lang')
                             ->where([ 'id' => 4 ])
                             ->one();
    
            $aliasIdsForBlog = [92, 93, 94];
            $this->view->params['aliases'] = \artbox\core\models\Alias::find()
                                                                      ->where(
                                                                          [
                                                                              'id' => $aliasIdsForBlog
                                                                          ]
                                                                      )
                                                                      ->all();
            
            return $this->render(
                'price',
                [
                    'page_stom' => $page_stom,
                    'page_cosm' => $page_cosm,
                ]
            );
        }
        
        public function actionComments()
        {
            $model = new CommentPage(
                [
                    'id' => 1,
                ]
            );
    
            $aliasIdsForBlog = [101, 102, 103];
            $this->view->params['aliases'] = \artbox\core\models\Alias::find()
                                                                      ->where(
                                                                          [
                                                                              'id' => $aliasIdsForBlog
                                                                          ]
                                                                      )
                                                                      ->all();
            
            return $this->render(
                'comments',
                [
                    'model' => $model,
                ]
            );
        }
        
        public function actionGallery()
        {
            $images = ( new Gallery() )->getImages();
    
            $aliasIdsForBlog = [86, 87, 88];
            $this->view->params['aliases'] = \artbox\core\models\Alias::find()
                                                                      ->where(
                                                                          [
                                                                              'id' => $aliasIdsForBlog
                                                                          ]
                                                                      )
                                                                      ->all();
            
            return $this->render(
                'gallery',
                [
                    'images' => $images,
                ]
            );
        }
    }
