<?php
    
    /**
     * @var View           $this
     * @var string         $content
     * @var SeoComponent   $seo
     * @var User           $user
     * @var PageCategory[] $pageCategories
     */
    
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use common\models\Feedback;
    use artbox\core\models\PageCategory;
    use artbox\core\models\User;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use artbox\core\components\imagemanager\models\ImageManager;
    use yii\bootstrap\ActiveForm;
    use yii\bootstrap\Nav;
    use yii\bootstrap\Html;
    use yii\db\ActiveQuery;
    use yii\helpers\Url;
    use yii\web\View;
    use frontend\widgets\SeoBreadcrumbs;
    use \artbox\core\models\Language;
    
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback(['scenario' => Feedback::SCENARIO_WRITE_US]);
    $appointment = new Feedback(['scenario' => Feedback::SCENARIO_APPOINTMENT]);
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    
    $pageCategories = PageCategory::find()
                                  ->with(
                                      [
                                          'lang',
                                          'pages' => function (ActiveQuery $query) {
                                              $query->with('lang.alias')
                                                    ->orderBy([ 'sort' => SORT_ASC ]);
                                          },
                                      ]
                                  )
                                  ->where([ 'status' => true ])
                                  ->orderBy([ 'sort' => SORT_ASC ])
                                  ->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = ImageManager::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getImagePathPrivate() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    );
    
    $this->registerMetaTag(
        [
            'name'    => 'robots',
            'content' => $seo->robots,
        ]
    );
    
    $this->registerJsFile(
        '/js/jquery.maskedinput.js',
        [
            'depends' => 'yii\web\JqueryAsset'
        ]
    );
    
    $js = <<<JS
        $("#feedback-phone, #appointment-phone").mask("+38(999)999-99-99");
JS;
    $this->registerJs($js, View::POS_READY);
    
?>

<?php $this->beginPage() ?>
  
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
      <link type="image/x-icon" href="/img/favicon.ico" rel="icon">
      <title><?= Html::encode($seo->title) ?></title>
        <?php $this->head() ?>

        <?php
            if(isset($this->params['model'])){
                echo \frontend\widgets\LanguageMarkupWidget::widget(
                    [
                        'languages' => ['ru', 'ua'],
                        'model' => $this->params['model']
                    ]
                );
            }
            else if( isset($this->params['aliases']) ) {
                echo \frontend\widgets\LanguageMarkupWidget::widget(
                    [
                        'languages' => ['ru', 'ua'],
                        'aliases' => $this->params['aliases']
                    ]
                );
            }
        ?>
        
        <!-- Google Tag Manager -->
        <script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
                new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
                j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
                'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
            })(window,document,'script','dataLayer','GTM-M6MFXLM');</script>
        <!-- End Google Tag Manager -->

        <!-- Global site tag (gtag.js) - Google Analytics -->
        <?php if (!empty($settings->ga_code)) { ?>
            <script async src="https://www.googletagmanager.com/gtag/js?id=UA-109405172-1"></script>
            <script>
                window.dataLayer = window.dataLayer || [];
                function gtag(){dataLayer.push(arguments);}
                gtag('js', new Date());

                gtag('config', '<?=$settings->ga_code?>');
            </script>
        <?php } ?>
        <style>
            .langs {
                text-transform: uppercase;
                line-height: 23px;
                margin-top: 2px;
                display: inline-block;
                margin-bottom: -2px;
                margin-left: 20px;
                margin-left:10px;
                display:inline-block;
            }
            .langs a.active {
                color: #5cbfa9!important;
                font-weight: bold;
                cursor:default;
                text-decoration:none;
            }
        </style>

    </head>
    <body>
        <?php $this->beginBody() ?>


        <!-- Google Tag Manager (noscript) -->
        <noscript><iframe src="https://www.googletagmanager.com/ns.html?id=GTM-M6MFXLM"
                          height="0" width="0" style="display:none;visibility:hidden"></iframe></noscript>
        <!-- End Google Tag Manager (noscript) -->


      <div id="all">
        <header>
          <!-- *** TOP ***
_________________________________________________________ -->
          <div id="top">
            <div class="container">
              <div class="row">
                <div class="col-xs-5 contact">
                  <p class="hidden-sm hidden-xs">
                      <?php
                          if (!empty($settings->phone)) {
                              echo \Yii::t('app', 'Связаться с нами ');
                              echo Html::a($settings->phone, "тел.: {$settings->phone}");
                              if (!empty($settings->email)) {
                                  echo \Yii::t('app', ' или ');
                                  echo Html::a($settings->email, "mailto:$settings->email");
                              }
                          }
                      ?>
                  </p>
                  <p class="hidden-md hidden-lg">
                    <a href="#" data-animate-hover="pulse"><i class="fa fa-phone"></i></a>
                    <a href="#" data-animate-hover="pulse"><i class="fa fa-envelope"></i></a>
                  </p>
                </div>
                <div class="col-xs-7">
                  <div class="social">
                      <?php
                          if (!empty($settings->facebook)) {
                              echo Html::a(
                                  Html::icon(
                                      'facebook',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->facebook,
                                  [
                                      'class' => 'external facebook',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->vk)) {
                              echo Html::a(
                                  Html::icon(
                                      'vk',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->vk,
                                  [
                                      'class' => 'external vk',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->google)) {
                              echo Html::a(
                                  Html::icon(
                                      'google-plus',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->google,
                                  [
                                      'class' => 'external gplus',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->twitter)) {
                              echo Html::a(
                                  Html::icon(
                                      'twitter',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->twitter,
                                  [
                                      'class' => 'external twitter',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->ok)) {
                              echo Html::a(
                                  Html::icon(
                                      'odnoklassniki',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  $settings->ok,
                                  [
                                      'class' => 'external odnoklassniki',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php
                          if (!empty($settings->email)) {
                              echo Html::a(
                                  Html::icon(
                                      'envelope',
                                      [
                                          'prefix' => 'fa fa-',
                                      ]
                                  ),
                                  "mailto:$settings->email",
                                  [
                                      'class' => 'email',
                                      'data'  => [
                                          'animate-hover' => 'pulse',
                                      ],
                                  ]
                              );
                          }
                      ?>
                      <?php $lang = explode("-",\Yii::$app->language);?>
                      <div class="langs">
                          <a<?php if($lang['0'] == 'en') echo ' class="active"'; else echo ' href="/en"';?>>en</a>
                          <a<?php if($lang['0'] == 'ua') echo ' class="active"'; else echo ' href="/ua"';?>>ua</a>
                      </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
          <!-- *** TOP END *** -->
          <!-- *** NAVBAR ***
  _________________________________________________________ -->
          <div class="navbar-affixed-top" data-spy="affix" data-offset-top="200">
            
            <div class="navbar navbar-default yamm" role="navigation" id="navbar">
              
              <div class="container">
                <div class="navbar-header">
                  
                  <a class="navbar-brand home" href="/">
                      <?php
                          echo ImageHelper::set($logo)
                                          ->setHeight(42)
                                          ->renderImage(
                                              [
                                                  'alt' => $settings->name,
                                              ]
                                          )
                      ?>
                  </a>
                  <div class="navbar-buttons">
                    <button type="button" class="navbar-toggle btn-template-main" data-toggle="collapse" data-target="#navigation">
                      <span class="sr-only">Toggle navigation</span>
                      <i class="fa fa-align-justify"></i>
                    </button>
                  </div>
                </div>
                
                <div class="navbar-collapse collapse" id="navigation">
                    <?php
                        $items = [];
                        $items[] = [
                            'label'   => \Yii::t('app', 'Услуги'),
                            'items'   => $this->render(
                                '_services',
                                [
                                    'pageCategories' => $pageCategories,
                                ]
                            ),
                            'options' => [
                                'class' => '_dropdown-wr',
                            ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'О клинике'),
                            'url'   => [
                                'page/view',
                                'id' => 6,
                            ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Галерея'),
                            'url'   => [ 'site/gallery' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Статьи'),
                            'url'   => [ 'blog/index' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Цены'),
                            'url'   => [ 'site/price' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Контакты'),
                            'url'   => [ 'site/contact' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Персонал'),
                            'url'   => [ 'persone/index' ],
                        ];
                        $items[] = [
                            'label' => \Yii::t('app', 'Отзывы'),
                            'url'   => [ 'site/comments' ],
                        ];
                        echo Nav::widget(
                            [
                                'items'   => $items,
                                'options' => [
                                    'class' => 'nav navbar-nav navbar-right',
                                ],
                            ]
                        );
                    ?>
                </div>
                
                
                <div class="collapse clearfix" id="search">
                  
                  <form class="navbar-form" role="search">
                    <div class="input-group">
                      <input type="text" class="form-control" placeholder="<?=\Yii::t('app', 'Поиск')?>">
                      <span class="input-group-btn">

                    <button type="submit" class="btn btn-template-main"><i class="fa fa-search"></i></button>

                </span>
                    </div>
                  </form>
                
                </div>
                <!--/.nav-collapse -->
              
              </div>
            
            
            </div>
            <!-- /#navbar -->
          
          </div>
          
          <!-- *** NAVBAR END *** -->
        
        </header>
        
        
        <!-- *** appointment MODAL ***
_________________________________________________________ -->
        <div class="forms_" id="appointment-modal" aria-labelledby="Login" style="display:none;" aria-hidden="true">
          <div class="forms_wr_">
            <div class="modal-header">
              <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times</button>
              <div class="modal-title" id="Login"><?=\Yii::t('app', 'Обратная связь')?></div>
            </div>
            <div class="modal-body">
              
                
                <?php
                    
                    
                    $formAppointment = ActiveForm::begin(
                        [
                            'id'     => 'appointment-form',
                            'method' => 'POST',
                            'action' => '/site/feedback',
                        ]
                    );
                    
                    echo Html::hiddenInput('type', 'appointment');
                    echo $formAppointment->field(
                        $appointment,
                        "name",
                        [
                            'options'  => [
                                'class' => 'form-group field-appointment-name',
                            ],
                            'template' => "<div class=\"on_input_\"></div>{label}\n{input}\n<p class=\"help-block help-block-error\"></p>",
                            'inputOptions' => [
                                'id' => 'appointment-name'
                            ],
                            'labelOptions' => [
                                'for' => 'appointment-name',
                                'class' => 'control-label'
                            ],
                        ]
                    )
                                         ->label(
                                             \Yii::t('app', 'Имя')
                                         );
    
                    echo $formAppointment->field(
                        $appointment,
                        "phone",
                        [
                            'options'  => [
                                'class' => 'form-group field-appointment-phone',
                            ],
                            'template' => "<div class=\"on_input_\"></div>{label}\n{input}\n<p class=\"help-block help-block-error\"></p>",
                            'inputOptions' => [
                                'id' => 'appointment-phone'
                            ],
                            'labelOptions' => [
                                'for' => 'appointment-phone',
                                'class' => 'control-label'
                            ],
                        ]
                    )
                                         ->label(
                                             \Yii::t('app', 'Номер телефона')
                                         );
    
                    echo $formAppointment->field(
                        $appointment,
                        "date",
                        [
                            'options'  => [
                                'class' => 'form-group field-appointment-date has-datepicker',
                            ],
                            'template' => "<div class=\"on_input_\"></div>{label}\n{input}\n<p class=\"help-block help-block-error\"></p>",
                            'inputOptions' => [
                                'id' => 'appointment-date'
                            ],
                            'labelOptions' => [
                                'for' => 'appointment-date',
                                'class' => 'control-label'
                            ],
                        ]
                    )
                                         ->label(
                                             \Yii::t('app', 'Дата')
                                         );
                    echo "<div class=\"datepicker-wr\">
                          <div id=\"datepicker\"></div>
                        </div>";
    
                    echo $formAppointment->field(
                        $appointment,
                        "time",
                        [
                            'options'  => [
                                'class' => 'form-group field-appointment-time',
                            ],
                            'template' => "<div class=\"on_input_\"></div>{label}\n{input}\n",
                            'inputOptions' => [
                                'id' => 'appointment-time'
                            ],
                            'labelOptions' => [
                                'for' => 'appointment-time',
                                'class' => 'control-label'
                            ],
                        ]
                    )
                                         ->label(
                                             \Yii::t('app', 'Время')
                                         );
    
                    $serviceItems = [ \Yii::t('app', "Услуга не выбрана") => \Yii::t('app', "Выберите услугу")];
                    foreach ($pageCategories as $pageCategory){
                        /**
                         * @var PageCategory $pageCategory
                         */
                        foreach ( $pageCategory->pages as $servicePage ){
                            /**
                             * @var \artbox\core\models\Page $servicePage
                             */
                            $pageTitle = $servicePage->lang->title;
                            $serviceItems[$pageTitle] = $pageTitle;
                        }
                    }
                    
                    echo $formAppointment->field(
                        $appointment,
                        "service",
                        [
                            'options'  => [
                                'class' => 'form-group field-appointment-service',
                            ],
                            'template' => "{label}\n{input}\n",
                            'inputOptions' => [
                                'id' => 'appointment-service'
                            ],
                            'labelOptions' => [
                                'for' => 'appointment-service',
                                'class' => 'control-label'
                            ],
                        ]
                    )
                                         ->dropDownList(
                                             $serviceItems,
                                             [
                                                 'options' => [
                                                     \Yii::t('app', "Услуга не выбрана") => [
                                                         'disabled' => true,
                                                         'selected' => true,
                                                     ]
                                                 ]
                                             ]
                                         )
                                         ->label(
                                             \Yii::t('app', "Услуга")
                                         );
                    
                    echo Html::tag(
                        "p",
                        Html::button(
                            \Yii::t('app', "Отправить"),
                            [
                                'type' => "submit",
                                'class' => "send-form btn btn-lg btn-template-primary"
                            ]
                        ),
                        [
                            'class' => "text-center"
                        ]
                    );
                    
                    $formAppointment::end();
                ?>
                
            
            </div>
          </div>
          <div class="overlay-new"></div>
        </div>
        
        <!-- *** appointment MODAL END *** -->
        
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        <div class="forms_" id="feedback-modal" aria-labelledby="Login" style="display:none;" aria-hidden="true">
          <div class="forms_wr_">
            <div class="modal-header">
              <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times</button>
              <div class="modal-title" id="Login"><?=\Yii::t('app', "Обратная связь")?></div>
            </div>
            <div class="modal-body">
                
                <?php $form = ActiveForm::begin(
                    [
                        'id'     => 'feedback-form',
                        'method' => 'POST',
                        'action' => '/site/feedback',
                    ]
                ); ?>
                
                <?= Html::hiddenInput('type', 'write_us');?>
                
                <?= $form->field($feedback, 'name')
                         ->textInput()
                        ->Label(\Yii::t('app', 'Имя')); ?>
                
                <?= $form->field($feedback, 'email')
                         ->textInput()
                    ->Label('Email'); ?>
                
                <?= $form->field($feedback, 'phone')
                         ->textInput()
                    ->Label(\Yii::t('app', 'Номер телефона')); ?>
                
                <?= $form->field($feedback, 'message')
                         ->textarea(
                             [
                                 'rows' => 4,
                             ]
                         )
                    ->Label(\Yii::t('app', 'Сообщение')); ?>
              
              <p class="text-center">
                  <?= Html::submitButton(
                      \Yii::t('app','Отправить'),
                      [
                          'class' => 'send-form btn btn-lg btn-template-primary',
                      ]
                  ) ?>
              </p>
                
                <?php ActiveForm::end(); ?>
            
            </div>
          </div>
          <div class="overlay-new"></div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** FeedBack MODAL ***
_________________________________________________________ -->
        <div class="success_" id="success-modal" aria-labelledby="Success" aria-hidden="true">
          <div class="forms_wr_">
            <div class="modal-header">
              <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times</button>
              <div class="modal-title" id="Success"><?=\Yii::t('app', 'Отправлено')?></div>
            </div>
            <div class="modal-body">
              
              <p><?=\Yii::t('app', 'Спасибо, ваша заявка отправлена')?></p>
              <p class="text-center">
                <button type="button" class="btn btn-template-primary" data-dismiss="modal"><?=\Yii::t('app', 'Закрыть')?></button>
              </p>
            </div>
          </div>
        </div>
        
        <!-- *** FeedBack MODAL END *** -->
        
        <!-- *** Breadcrumbs *** -->
          <?php
              if (!$isHome) {
                  ?>
                <div id="heading-breadcrumbs">
                  <div class="container">
                    <div class="row">
                      <div class="col-md-7">
                        <h1><?= \Yii::t('app', $seo->h1) ?></h1>
                      </div>
                      <div class="col-md-5">
                          <?= SeoBreadcrumbs::widget(
                              [
                                  'links' => isset($this->params[ 'breadcrumbs' ]) ? $this->params[ 'breadcrumbs' ] : [],
                                  'homeLink' => [
                                      'label' => "<span itemprop='name'>".\Yii::t('app', 'Главная')."</span>",
                                      'url' => '/' . Language::getCurrent()->url,
                                      'itemprop' => 'item',
                                  ],
                                  'activeItemUrl' => \Yii::$app->request->getAbsoluteUrl(),
                              ]
                          ) ?>
                      
                      </div>
                    </div>
                  </div>
                </div>
                  <?php
              }
          ?>
        <!-- *** Breadcrumbs END *** -->
          
          <?= $content ?>
        
        <!-- *** FOOTER ***
_________________________________________________________ -->
        
        <footer id="footer">
          <div class="container">
            <div class="col-md-6 col-sm-12">
                <?php
                    if (!empty($settings->about)) {
                        ?>
                      <h4><?php echo \Yii::t('app', 'About us'); ?></h4>
                      <p><?php echo $settings->about; ?></p>
                        <?php
                    }
                ?>
              <a href="#" class="btn btn-template-transparent-primary modal-link" data-form="feedback-modal" data-modalname="<?=\Yii::t('app', 'Обратная связь')?>"><?=\Yii::t('app', 'Написать нам')?></a>
            </div>
            
            <div class="col-md-4 col-sm-12 col-md-offset-2">
              
              <h4><?php echo \Yii::t('app', 'Контакты'); ?></h4>
              
              <p>
                  <?php
                      if (!empty($settings->office)) {
                          echo \Yii::t(
                                  'app',
                                  'Офис {office}',
                                  [
                                      'office' => $settings->office,
                                  ]
                              ) . Html::tag('br');
                      }
                      $notEng = (Language::getCurrent()->url !=='en')?true:false;

                      if (!empty($settings->street)) {

                          echo (($notEng)?$settings->street
                          :'m. Poznyaki, st. Sribnokilskaya');
                          if (!empty($settings->house)) {
                              echo " " .
                                  $settings->house

                              ;
                          }
                          echo Html::tag('br');
                      }
                      if (!empty($settings->city)) {
                          echo (($notEng)?$settings->city:"Kyiv");
                          echo Html::tag('br');
                      }
                      if (!empty($settings->country)) {
                          echo Html::tag('strong',
                              (($notEng)?$settings->country:"Ukraine"));
                      }
                  ?>
              </p>
                
                <?= Html::a(
                    \Yii::t('app', 'На страницу контактов'),
                    [ 'site/contact' ],
                    [
                        'class' => 'btn btn-small btn-template-transparent-primary',
                    ]
                ) ?>
              
              <hr class="hidden-md hidden-lg hidden-sm">
            
            </div>
            
            <div class="col-md-6 footer-copyrights">
                <p class="pull-left">
                    <span>&copy; <?= date('Y') ?>. <?= $settings->name; ?></span><span class="footer_logo_aw"><?=\Yii::t('app', 'Создание сайтов')?> - <a href="//artweb.ua" title="ArtWeb - <?=\Yii::t('app', 'Создание сайтов')?>" target="_blank">ArtWeb.ua</a></span>
                </p>
            </div>
          </div>
          <!-- /.container -->
        </footer>
        <!-- /#footer -->
        
        <!-- *** FOOTER END *** -->
        
        <span id="back-to-top" title="Back to top"><i class="fa fa-arrow-up"></i></span>
      
      </div>
      <div id="overlay" style="display:none;"></div>
      <!-- /#all -->
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>